This module allows to handle use of reusable containers in POS,
this is useful to handle selling product in bulk without having to calculate
the tare of the container.

Each container is identified by a barcode, the weight is stored in Odoo.
